@@ -16,7 +16,7 @@
 
 #include "libkdeedu_science_export.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 
 /**
